@@ -20,9 +20,13 @@ let comment_re = Re.Pcre.regexp "\\s*#.*$"
 
 let remove_comment str = Re.Pcre.substitute ~rex:comment_re str ~subst:(fun _ -> "")
 
+let blank_line_re = Re.Pcre.regexp "^\\s*$"
+
+let remove_blank_line str = Re.Pcre.substitute ~rex:blank_line_re str ~subst:(fun _ -> "")
+
 let whitespace_re = Re.Pcre.regexp "\\s+"
 
-let words_of_line line = Re.Pcre.split ~rex:whitespace_re (remove_comment line)
+let words_of_line line = Re.Pcre.split ~rex:whitespace_re (remove_blank_line (remove_comment line))
 
 let map = ref []
 
@@ -40,7 +44,7 @@ let get = get_generic (fun x -> x)
 let get_int = get_generic int_of_string
 
 let bool_of_string str =
-  match String.lowercase str with
+  match String.lowercase_ascii str with
   | "true"  | "yes" | "on"  | "1" -> true
   | "false" | "no"  | "off" | "0" -> false
   | _ -> failwith ("not a boolean value: " ^ str)
