@@ -64,12 +64,36 @@ let is_diff_index file =
 let is_pdiff file =
   Filename.basename file <> "Index" && diff_index_dir file
 
+let is_dep11_icons file =
+  String.starts_with ~prefix:"icons-" (Filename.basename file) &&
+  Filename.basename (Filename.dirname file) = "dep11"
+
 let is_i18n_index file =
   Filename.basename file = "Index" &&
   Filename.basename (Filename.dirname file) = "i18n"
 
+let installer_current_re =
+  Re.Pcre.regexp "/installer-[a-z0-9]+/current/"
+
+let is_installer_current file =
+  Re.execp installer_current_re file
+
 let immutable_suffixes =
-  [".deb"; ".udeb"; ".dsc"; ".diff.gz"] @ compressed_versions ".tar"
+  [".deb"; ".udeb"; ".dsc"; ".diff.gz"]
+
+let is_immutable_suffix sfx =
+  List.exists sfx immutable_suffixes
+
+let tarball_suffixes =
+  compressed_versions ".tar"
+
+let is_immutable_tarball file sfx =
+  List.exists sfx tarball_suffixes &&
+  not (is_dep11_icons file) &&
+  not (is_installer_current file)
 
 let immutable file =
-  List.exists (Filename.check_suffix file) immutable_suffixes || is_pdiff file
+  let sfx = Filename.check_suffix file in
+  is_immutable_suffix sfx ||
+  is_immutable_tarball file sfx ||
+  is_pdiff file
