@@ -15,6 +15,21 @@ let create_bad ctx =
   close_out chan;
   file
 
+let blank_lines =
+  ["";
+   " ";
+   "\t";
+   "  \t  # comment"]
+
+let create_blank ctx =
+  let file, chan = bracket_tmpfile ctx in
+  let print_line (l) =
+    output_string chan (l ^ "\n")
+  in
+  iter print_line blank_lines;
+  close_out chan;
+  file
+
 let test_bindings =
   ["$debug", "true";
    "$interval", "120";
@@ -36,6 +51,7 @@ let cleanup () _ = Config_file.reset ()
 let read_good ctx =
   bracket
     (fun ctx ->
+      Config_file.reset ();
       Config_file.read (create_good ctx))
     cleanup ctx
 
@@ -46,6 +62,10 @@ let suite = [
    (fun ctx ->
       let file = bracket create_good tear_down ctx in
       assert_equal () (Config_file.read file));
+   "(read \"blank\")" >::
+   (fun ctx ->
+      let file = bracket create_blank tear_down ctx in
+      assert_equal () (Config_file.read file));
    "(read \"bad\")" >::
    (fun ctx ->
      let file = bracket create_bad tear_down ctx in
