@@ -8,6 +8,7 @@ let tests = List.concat
     [Util_test.suite;
      Config_file_test.suite;
      Config_test.suite;
-     Control_file_test.suite]
+     Control_file_test.suite;
+     Release_test.suite]
 
 let () = run_test_tt_main (test_list tests)
