@@ -30,7 +30,7 @@ val download :
   string ->
   ?headers:string list ->
   ?header_callback:(string -> unit) ->
-  (string -> int -> int -> unit) -> unit
+  (bytes -> int -> int -> unit) -> unit
 
 (* Download a file from a remote repository *)
 
